
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.21.7',
    'branch_nick': 'patch-0-Release__1_21_7_preparation',
    'revision_id': '8e7e22354ba4ca5cfbc8ea945dbe8c6707e42c02',
    'revno': 9122
}
